from src.utils.email import email_tool
from src.utils.youtube import youtube_tool
from src.utils.weather import weather_tool
from src.utils.google_search import search_tool

tools = [
    email_tool,
    search_tool,
    weather_tool,
    youtube_tool,
]
